# README

## Group Number: 17
## Group Members: Nick Stern, Vincent Viego, Summer Yuan, Zach Wehrwein

<!-- Badges -->

[![Build Status](https://travis-ci.org/VV-NS-CY-ZW-CS-207-Organization/cs207-FinalProject.svg?branch=master)](https://travis-ci.org/VV-NS-CY-ZW-CS-207-Organization/cs207-FinalProject)

[![CoverageStatus](https://coveralls.io/repos/github/VV-NS-CY-ZW-CS-207-Organization/cs207-FinalProject/badge.svg?branch=master)](https://coveralls.io/github/VV-NS-CY-ZW-CS-207-Organization/cs207-FinalProject?branch=master)

The **Dotua** library provides expressive, efficient, and easy to use
support for forward and reverse automatic differentiation.  This library
was completed as a project for Harvard CS207: Systems Development for
Computational Science.

For more information on the course [click here](https://iacs-cs-207.github.io/cs207-F18/).

For more information about the library [read our documentation](https://github.com/VV-NS-CY-ZW-CS-207-Organization/cs207-FinalProject/blob/master/docs/documentation.md)
